<?php
require './analytics-php/vendor/autoload.php';
use Segment\Segment;
class SegmentAnalytics {

  public $segmentEventName = "";
  public $customerID = "";
  public $orderID = "";
  private $productList = [];

  public function __construct($write_key, $ssl, $debug){
    Segment::init($write_key, [
      "consumer" => "lib_curl",
      "debug" => $debug,
      "ssl" => $ssl,
      "error_handler" => function ($code, $msg) {
        echo json_encode(['error_code'=>$code, 'error_msg'=>$msg]);
      }
    ]);
  }

  public function getProductList(){
    return $this->productList;
  }

  public function clearProductList(){
    $this->productList = [];
  }

  public function addProductToList($id, $name, $price, $qty=1){
    $prd = [
            "product_id" => $id,
            "name" => $name,
            "price" => $price,
            "quantity" => $qty
          ];
    array_push($this->productList, $prd);
  }

  public function postGglEnhancedConversions($conversionLbl, $fname, $lname, $email, $phone, $total, $city, $country, $userAgent){
    $payload = [
      "userId" => $this->customerID,
      "event" => $this->segmentEventName,
      "conversionLabel" => $conversionLbl,
      "properties" => [
        "firstName" => $fname,
        "lastName" => $lname,
        "email" => $email,
        "phone" => $phone,
        "orderId" => $this->orderID,
        "total" => $total,
        "currency" => "USD",
        "address" => [
          "city" => $city,
          "country" => $country,
        ]
      ],
      "context" => [
        "userAgent" => $userAgent,
      ],
      "integrations" => [
        "All" => false,
        "Google Enhanced Conversions" => true
      ]
    ];
    $this->track($payload);
  }

  public function postGA4PurchaseEvent($client_id, $affid, $email, $shipping, $total, $tax){
    $payload = [
      "userId" => $this->customerID,
      "clientId" => $client_id,
      "event" => $this->segmentEventName,
      "properties" => [
        "affiliation" => $affid,
        "tax" => $tax,
        "shipping" => $shipping,
        "order_id" => $this->orderID,
        "total" => $total,
        "currency" => "USD",
        "products" => $this->productList
      ],
      "integrations" => [
        "All" => false,
        "Google Analytics 4" => true
      ]
    ];
    $this->track($payload);
  }

  public function postTiktokPurchaseEvent($email, $phone, $total, $ttclid, $url, $userAgent){
    $payload = [
      "userId" => $this->customerID,
      "event" => $this->segmentEventName,
      "orderId" => $this->orderID,
      "properties" => [
        "email" => $email,
        "phone" => $phone,
        "ttclid" => $ttclid,
        "currency" => "USD",
        "value" => $total,
        "products" => $this->productList
      ],
      "context" => [
        "page" => [
          "url" => $url
        ],
        "userAgent" => $userAgent,
        "ip" => $_SERVER['SERVER_ADDR']
      ],
      "integrations" => [
        "All" => false,
        "Tiktok Conversions" => true
      ]
    ];
    $this->track($payload);
  }


  private function track($payload){
    Segment::track($payload);
    print_r(Segment::flush());
  }
}